@@ -3,7 +3,7 @@
 from validictory.validator import SchemaValidator, ValidationError, SchemaError
 
 __all__ = ['validate', 'SchemaValidator', 'ValidationError', 'SchemaError']
-__version__ = '0.7.2'
+__version__ = '0.8.0'
 
 
 def validate(data, schema, validator_cls=SchemaValidator,
@@ -43,5 +43,5 @@ if __name__ == '__main__':
         obj = json.load(infile)
         schema = json.load(schemafile)
         validate(obj, schema)
-    except ValueError, e:
+    except ValueError as e:
         raise SystemExit(e)
