@@ -1,5 +1,12 @@
 from unittest import TestCase
 import datetime
+import sys
+
+if sys.version_info[0] == 3:
+    unicode_str = '\u2603'
+else:
+    unicode_str = unicode('snowman')
+
 
 import validictory
 
@@ -20,7 +27,7 @@ class TestType(TestCase):
         for x in [data1, data2]:
             try:
                 validictory.validate(x, schema)
-            except ValueError, e:
+            except ValueError as e:
                 self.fail("Unexpected failure: %s" % e)
 
         self.assertRaises(ValueError, validictory.validate, data3, schema)
@@ -29,7 +36,7 @@ class TestType(TestCase):
         for x in valids:
             try:
                 validictory.validate(x, {"type":typename})
-            except ValueError, e:
+            except ValueError as e:
                 self.fail("Unexpected failure: %s" % e)
 
         for x in invalids:
@@ -42,7 +49,7 @@ class TestType(TestCase):
         self._test_type('integer', valid_ints, invalid_ints)
 
     def test_string(self):
-        valids = ["abc", u"unicode"]
+        valids = ["abc", unicode_str]
         invalids = [1.2, 1, {"test":"blah"}, [32, 49], None, True]
         self._test_type('string', valids, invalids)
 
@@ -81,7 +88,7 @@ class TestType(TestCase):
         for x in valids:
             try:
                 validictory.validate(x, {})
-            except ValueError, e:
+            except ValueError as e:
                 self.fail("Unexpected failure: %s" % e)
 
     def test_multi(self):
@@ -96,7 +103,7 @@ class TestDisallow(TestType):
         for x in invalids:
             try:
                 validictory.validate(x, {"disallow":typename})
-            except ValueError, e:
+            except ValueError as e:
                 self.fail("Unexpected failure: %s" % e)
 
         for x in valids:
@@ -132,7 +139,7 @@ class TestCustomType(TestCase):
         for x in valids:
             try:
                 validator.validate(x, {"type":typename})
-            except ValueError, e:
+            except ValueError as e:
                 self.fail("Unexpected failure: %s" % e)
 
         for x in invalids:
